Package: FastqCleaner
Type: Package
Title: A Shiny Application for Quality Control, Filtering and Trimming
        of FASTQ Files
Version: 1.29.0
Date: 2022-05-01
Authors@R: c(person(given = "Leandro", family = "Roser", role = c("aut", "cre"), 
             email = "learoser@gmail.com"), 
             person(given = "Fernán", family = "Agüero", role = "aut"),
             person(given = "Daniel", family = "Sánchez", role = "aut"))
Description: An interactive web application for quality control,  filtering and trimming of FASTQ files. This user-friendly tool combines a pipeline for data processing  based on Biostrings and ShortRead infrastructure, with a cutting-edge visual environment.
             Single-Read and Paired-End files can be locally processed. Diagnostic interactive plots (CG content, per-base sequence quality, etc.) are provided for both the input and output files.
License: MIT + file LICENSE
Imports: methods, shiny, stats, IRanges, Biostrings, ShortRead, DT,
        S4Vectors, graphics, htmltools, shinyBS, Rcpp (>= 0.12.12)
Suggests: BiocStyle, testthat, knitr, rmarkdown
LinkingTo: Rcpp
Collate: 'roxygen.auxiliar.R' 'auxiliar.R' 'matching.R'
        'server_functions.R' 'n_filter.R' 'seq_filter.R'
        'complex_filter.R' 'adapter_filter.R' 'launch_fqc.R'
        'length_filter.R' 'fixed_filter.R' 'trim3q_filter.R'
        'unique_filter.R' 'plotObjects.R' 'qmean_filter.R' 'simulate.R'
        'RcppExports.R'
biocViews:
        QualityControl,Sequencing,Software,SangerSeq,SequenceMatching
VignetteBuilder: knitr
Packaged: 2025-10-31 21:47:31 UTC; biocbuild
Encoding: UTF-8
RoxygenNote: 7.1.2
git_url: https://git.bioconductor.org/packages/FastqCleaner
git_branch: devel
git_last_commit: 464323c
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: yes
Author: Leandro Roser [aut, cre],
  Fernán Agüero [aut],
  Daniel Sánchez [aut]
Maintainer: Leandro Roser <learoser@gmail.com>
