# Generated by roxygen2: do not edit by hand

export(adapter_filter)
export(check_encoding)
export(complex_filter)
export(fixed_filter)
export(inject_letter_random)
export(launch_fqc)
export(length_filter)
export(n_filter)
export(qmean_filter)
export(random_length)
export(random_qual)
export(random_seq)
export(seq_filter)
export(seq_names)
export(trim3q_filter)
export(unique_filter)
import(Rcpp)
import(htmltools)
importFrom(Biostrings,BStringSet)
importFrom(Biostrings,DNAString)
importFrom(Biostrings,DNAStringSet)
importFrom(Biostrings,PhredQuality)
importFrom(Biostrings,dinucleotideFrequency)
importFrom(Biostrings,oligonucleotideFrequency)
importFrom(Biostrings,quality)
importFrom(Biostrings,replaceLetterAt)
importFrom(Biostrings,reverseComplement)
importFrom(Biostrings,trimLRPatterns)
importFrom(DT,dataTableOutput)
importFrom(DT,renderDataTable)
importFrom(IRanges,end)
importFrom(IRanges,narrow)
importFrom(IRanges,start)
importFrom(IRanges,width)
importFrom(S4Vectors,isConstant)
importFrom(ShortRead,FastqSampler)
importFrom(ShortRead,ShortReadQ)
importFrom(ShortRead,id)
importFrom(ShortRead,nFilter)
importFrom(ShortRead,sread)
importFrom(ShortRead,yield)
importFrom(ShortRead,occurrenceFilter)
importFrom(graphics,hist)
importFrom(methods,as)
importFrom(methods,is)
importFrom(shinyBS,bsAlert)
importFrom(shinyBS,bsModal)
importFrom(shinyBS,bsPopover)
importFrom(stats,quantile)
useDynLib(FastqCleaner)
