% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotG}
\alias{plotG}
\title{plotG}
\usage{
plotG(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
CG content distribution plot
}
\description{
plotG
}
\keyword{internal}
