% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotE}
\alias{plotE}
\title{plotE}
\usage{
plotE(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Per cycle base proportion plot
}
\description{
plotE
}
\keyword{internal}
