% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotC}
\alias{plotC}
\title{plotC}
\usage{
plotC(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Mean quality of reads distribution plot
}
\description{
plotC
}
\keyword{internal}
