% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotH}
\alias{plotH}
\title{plotH}
\usage{
plotH(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Read length distribution
}
\description{
plotH
}
\keyword{internal}
