% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotA}
\alias{plotA}
\title{plotA}
\usage{
plotA(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Per cycle quality  plot
}
\description{
plotA
}
\keyword{internal}
