% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auxiliar.R
\name{asc2int}
\alias{asc2int}
\title{ASCII to integer}
\usage{
asc2int(x)
}
\value{
Integer
}
\description{
ASCII to integer
}
\keyword{internal}
