% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotB}
\alias{plotB}
\title{plotB}
\usage{
plotB(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Per cycle mean base quality plot
}
\description{
plotB
}
\keyword{internal}
