% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotJ}
\alias{plotJ}
\title{plotJ}
\usage{
plotJ(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Relative kmer diversity plot
}
\description{
plotJ
}
\keyword{internal}
