% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auxiliar.R
\name{isNaturalNumber}
\alias{isNaturalNumber}
\title{Is natural number}
\usage{
isNaturalNumber(x)
}
\value{
Logical
}
\description{
Is natural number
}
\keyword{internal}
