% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auxiliar.R
\name{int2asc}
\alias{int2asc}
\title{Integer to ASCII}
\usage{
int2asc(n)
}
\value{
ASCII character
}
\description{
Integer to ASCII
}
\keyword{internal}
