% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotObjects.R
\name{plotI}
\alias{plotI}
\title{plotI}
\usage{
plotI(x, nplots = 1, theFile = c("input", "output"), sampleSize)
}
\value{
Read ocurrence distribution plot
}
\description{
plotI
}
\keyword{internal}
